<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.0">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Informacije</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Prevoditelji</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>YouTube%1 preglednik za SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Inačica: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Prijenosna inačica</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Kompilirano s Qt %1 (koristeći %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Posjetite našu web stranicu za noviju inačicu:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Mnogo ljudi je doprinjelo s prijevodima.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Vi isto tako možete pomoći u prijevodu SMPlayera na vaš jezik.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Posjetite %1 i pridružite se prevoditeljskom timu.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Kliknite ovdje kako bi vidjeli timove prevoditelje na transifexu</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="138"/>
        <source>Home</source>
        <translation>Naslovnica</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="141"/>
        <source>Navigation</source>
        <translation>Navigacija</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="149"/>
        <source>Zoom +</source>
        <translation>Uvećaj +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="153"/>
        <source>Zoom -</source>
        <translation>Smanji -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="157"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Navigacija</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="172"/>
        <source>&amp;View</source>
        <translation>&amp;Prikaz</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="173"/>
        <source>Toolbar</source>
        <translation>Alatna traka</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="177"/>
        <source>Statusbar</source>
        <translation>Traka stanja</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="182"/>
        <source>&amp;Settings</source>
        <translation>&amp;Postavke</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="194"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="198"/>
        <source>&amp;Update YouTube playback support</source>
        <translation>&amp;Nadopuni Youtube podršku reprodukcije</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="200"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation>&amp;Instaliraj / Nadopuni Youtube podršku reprodukcije</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="206"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;O SMTubu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="331"/>
        <source>Download video using an external service</source>
        <translation>Preuzmite video snimku pomoću vanjske usluge</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="332"/>
        <source>Download</source>
        <translation>Preuzimi</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="578"/>
        <source>No video found</source>
        <translation>Nema pronađenih video snimaka</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Nemoguće je pronaći URL za ovu video snimku.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="610"/>
        <source>About...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="611"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="317"/>
        <source>Loading... %1%</source>
        <translation>Učitavanje... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation>Preuzimanje...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation>Povezivanje s %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation>Youtube kôd je uspješno instaliran.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation>Instalirana inačica: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation>Uspješno</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation>Nije moguće spremiti %1.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Greška se dogodila pri preuzimanju datoteke:&lt;br&gt;%1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation>%1 nije uspio u komunikaciji s youtube-dl. Ili nije instaliran ili ispravno ne radi.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Nemoguće je pronaći URL za ovu video snimku.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation>Možda trebate nadopuniti youtube-dl.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation>Kako bi mogli reproducirati YouTube video snimke, %1 treba vanjsku aplikaciju nazvanu youtube-dl.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation>Ovu komponentu je potrebno redovito nadopunjavati.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation>Možete ju nadopuniti jednostavno ponovnom instalacijom SMPlayera. Instalacijski program će preuzeti i instalirati najnoviju inačicu.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation>Instaliraj / Nadopuni Youtube podršku</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="232"/>
        <source>In order to play YouTube videos, %1 needs the help of an external application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="233"/>
        <source>%1 can download and install this application for you.</source>
        <translation>%1 može preuzeti i instalirati tu aplikaciju umjesto vas.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="234"/>
        <source>It will be downloaded from the official website and installed as %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="235"/>
        <source>Would you like to proceed?</source>
        <translation>Želite li nastaviti?</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="239"/>
        <location filename="../codedownloader.cpp" line="242"/>
        <source>Install YouTube support?</source>
        <translation>Instaliraj Youtube podršku?</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Općenito</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation>D&amp;odaj...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="178"/>
        <source>&amp;Players</source>
        <translation>&amp;Reproduktori</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="226"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Up</source>
        <translation>Gore</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Reprodukcija</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Željena &amp;kvaliteta:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation>Stranice</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation>&amp;Stranica:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation>Ured&amp;i...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation>Ob&amp;riši</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="152"/>
        <source>YouTube support application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.ui" line="237"/>
        <source>Delete</source>
        <translation>Obriši</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="261"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="274"/>
        <source>A&amp;dd predefined players</source>
        <translation>D&amp;odaj unaprijed određen reproduktor</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="310"/>
        <source>&amp;Interface</source>
        <translation>&amp;Sučelje</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="318"/>
        <source>&amp;Style:</source>
        <translation>&amp;Izgled:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="354"/>
        <source>Font:</source>
        <translation>Slova:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="368"/>
        <source>C&amp;hange...</source>
        <translation>P&amp;romijeni...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Preuzimanje</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Preuzmi video snimke pomoću &amp;vanjske usluge</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="202"/>
        <source>Down</source>
        <translation>Dolje</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="82"/>
        <source>Default</source>
        <translation>Zadano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="460"/>
        <source>yt-dlp (based on youtube-dl with improvements)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="478"/>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Kliknite za odabir datoteke ili mape</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>Otvori u &amp;YouTubu</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Spremi poveznicu...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>Kopiraj &amp;poveznicu u međuspremnik</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Otvori poveznicu u ovom prozoru</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>&amp;Kopiraj tekst u međuspremnik</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Otvori poveznicu u &amp;novom prozoru</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Gledaj sa</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>&amp;Slušaj sa</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>&amp;Gledaj sa %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="145"/>
        <source>Play &amp;audio with %1</source>
        <translation>&amp;Slušaj sa %1</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="154"/>
        <source>Play video with a &amp;web browser</source>
        <translation>Gledaj video snimku u &amp;web pregledniku</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Uredi reproduktor</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Naziv:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Izvršne datoteke:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Parametri:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Ovaj reproduktor podržava &amp;video stranice</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Ovaj reproduktor može reproducirati &amp;Internet TV</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Željena &amp;kvaliteta:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Dodaj u &amp;izbornik:</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Nepoznato</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Video i zvuk</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Zadano</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../version.cpp" line="48"/>
        <source>%1 (revision %2) %3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../version.cpp" line="50"/>
        <source>%1 (revision %2)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation>Uredi stranicu</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Naziv:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation>&amp;URL web stranice:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation>&amp;URL tražilice:</translation>
    </message>
</context>
</TS>